/* SPDX-License-Identifier: BSD-2-Clause */
/*
 * Copyright (c) 2014, STMicroelectronics International N.V.
 * All rights reserved.
 */

#ifndef USER_TA_HEADER_DEFINES_H
#define USER_TA_HEADER_DEFINES_H

#include <ta_storage.h>

#define TA_UUID TA_STORAGE_UUID

#define TA_FLAGS		0
#define TA_STACK_SIZE		(2 * 1024)
#define TA_DATA_SIZE		(64 * 1024)

#endif
